# rosinenpicker

![Python Packaging](https://github.com/joheli/rosinenpicker/workflows/Packaging/badge.svg)

'Rosinenpicker' is German for 'cherry picker'. Which explains what this program does: it goes through a list of documents to extract *just those juicy bits* **you** are interested in. It uses regular expressions to accomplish this. But please do read on to learn how to use the program. 

# Installation

Please fire up your console and type:

```
pip install rosinenpicker
```

This should add the executable `rosinenpicker` to `PATH`, making it accessible from the console.

# Usage

coming soon